=======
History
=======

0.5.0 (2019-01-06)
------------------

* Major revamp: Does not require Heroku CLI anymore. Uses Heroku API instead.
* Added --version/-v to check version
* Minor improvements


0.4.0 (2018-12-30)
------------------

* Detect Heroku installation and issues and launch appropriate URLs in browser to guide user
* Minor improvements


0.3.0 (2018-12-29)
------------------

* add feature to set alternate values during run
* cleanup and minor improvements

0.2.0 (2018-12-24)
------------------

* First release on PyPI.
